# Copyright 2015 Red Hat, Inc.
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
require 'puppet/provider/package'

Puppet::Type.type(:package).provide :norpm, :source => :rpm, :parent => :rpm do
  desc "RPM packaging provider that does not install anything."

  def latest
    @resource.fail "'latest' is unsupported by this provider."
  end

  def install
    true
  end

  def uninstall
    true
  end

  def update
    true
  end

  def purge
    true
  end

  def self.instances
    return []
  end

end
